summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--NEWS4
-rw-r--r--__init__.py18
-rw-r--r--processors/query_processor.py (renamed from processors/filter_processor.py)6
3 files changed, 16 insertions, 12 deletions
diff --git a/NEWS b/NEWS
index 71a2eab..05bdf54 100644
--- a/NEWS
+++ b/NEWS
@@ -9,6 +9,10 @@ IN DEVELOPMENT
COMPATIBILITY BREAKS:
+ * The ``fast-import-filter`` command is now called
+ ``fast-import-query``.
+ (Ian Clatworthy)
+
* The ``--inv-fulltext`` option is no longer supported. It was
only used in experimental mode for old versions of bzrlib so
it added more complexity than value. (Ian Clatworthy)
diff --git a/processors/filter_processor.py b/processors/query_processor.py
index b778cc1..dfee745 100644
--- a/processors/filter_processor.py
+++ b/processors/query_processor.py
@@ -14,7 +14,7 @@
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-"""Import processor that filters the input (and doesn't import)."""
+"""Import processor that queries the input (and doesn't import)."""
from bzrlib.plugins.fastimport import (
@@ -23,8 +23,8 @@ from bzrlib.plugins.fastimport import (
)
-class FilterProcessor(processor.ImportProcessor):
- """An import processor that filters the input.
+class QueryProcessor(processor.ImportProcessor):
+ """An import processor that queries the input.
No changes to the current repository are made.
"""
diff --git a/__init__.py b/__init__.py
index 26343bf..77444c2 100644
--- a/__init__.py
+++ b/__init__.py
@@ -37,7 +37,7 @@ online help for the commands::
bzr help fast-import
bzr help fast-import-info
- bzr help fast-import-filter
+ bzr help fast-import-query
To report bugs or publish enhancements, visit the bzr-fastimport project
page on Launchpad, https://launchpad.net/bzr-fastimport.
@@ -148,7 +148,7 @@ class cmd_fast_import(Command):
Import a Mercurial repository into Bazaar.
"""
hidden = True
- _see_also = ['fast-import-info', 'fast-import-filter']
+ _see_also = ['fast-import-info', 'fast-import-query']
takes_args = ['source']
takes_options = ['verbose',
Option('info', type=str,
@@ -227,8 +227,8 @@ class cmd_fast_import_info(Command):
return _run(source, info_processor.InfoProcessor, None, {}, verbose)
-class cmd_fast_import_filter(Command):
- """Filter a fast-import stream displaying selected commands.
+class cmd_fast_import_query(Command):
+ """Query a fast-import stream displaying selected commands.
To specify standard input as the input stream, use a source
name of '-'. To specify the commands to display, use the -C
@@ -247,11 +247,11 @@ class cmd_fast_import_filter(Command):
Examples::
front-end > xxx.fi
- bzr fast-import-filter xxx.fi -Creset -Ctag
+ bzr fast-import-query xxx.fi -Creset -Ctag
Show all the fields of the reset and tag commands.
- bzr fast-import-filter xxx.fi -Ccommit=mark,merge
+ bzr fast-import-query xxx.fi -Ccommit=mark,merge
Show the mark and merge fields of the commit commands.
"""
@@ -265,13 +265,13 @@ class cmd_fast_import_filter(Command):
]
aliases = []
def run(self, source, verbose=False, commands=None):
- from bzrlib.plugins.fastimport.processors import filter_processor
+ from bzrlib.plugins.fastimport.processors import query_processor
from bzrlib.plugins.fastimport import helpers
params = helpers.defines_to_dict(commands)
- return _run(source, filter_processor.FilterProcessor, None, params,
+ return _run(source, query_processor.QueryProcessor, None, params,
verbose)
register_command(cmd_fast_import)
register_command(cmd_fast_import_info)
-register_command(cmd_fast_import_filter)
+register_command(cmd_fast_import_query)